/* ###*B*###
 * ERIKA Enterprise - a tiny RTOS for small microcontrollers
 *
 * Copyright (C) 2002-2011  Evidence Srl
 *
 * This file is part of ERIKA Enterprise.
 *
 * ERIKA Enterprise is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation, 
 * (with a special exception described below).
 *
 * Linking this code statically or dynamically with other modules is
 * making a combined work based on this code.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this code with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under
 * terms of your choice, provided that you also meet, for each linked
 * independent module, the terms and conditions of the license of that
 * module.  An independent module is a module which is not derived from
 * or based on this library.  If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so.  If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * ERIKA Enterprise is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 2 along with ERIKA Enterprise; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 * ###*E*### */

/** 
	@file ee_utils.c
	@brief Functions to initialize the RTOS services
	@author Gianluca Franchino
	@author Giuseppe Serano
	@date 2011
*/ 

#include "ee_internal.h"
#include "ee_irq.h"
//~ #include "cpu/cortex_mx/inc/ee_nvic.h"

extern void EE_set_switch_context_pri(void);

/* Function used to calculate the initialize the system */
void EE_system_init(void)
{

  register EE_UREG flags;

  flags = EE_hal_suspendIRQ();

	/* 
	 * Set the priority of PendSV to the minimum one
	 * PendSV is the software interrupt used for context switch
	 */
	EE_set_switch_context_pri();

#ifdef	__CORTEX_M4__

#ifdef	EE_CORTEX_MX_SYSTICK_ISR
#ifdef	EE_CORTEX_MX_SYSTICK_ISR_PRI
	NVIC_SYS_PRI3_R |= (
	  EE_CORTEX_MX_SYSTICK_ISR_PRI << NVIC_SYS_PRI3_TICK_S
	);
#endif
#endif

#ifdef	EE_CORTEX_MX_INT_00_ISR
#ifdef	EE_CORTEX_MX_INT_00_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_00_NUM, EE_CORTEX_MX_INT_00_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_00_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_00_NUM);
#endif	/* EE_CORTEX_MX_INT_00_ISR */

#ifdef	EE_CORTEX_MX_INT_01_ISR
#ifdef	EE_CORTEX_MX_INT_01_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_01_NUM, EE_CORTEX_MX_INT_01_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_01_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_01_NUM);
#endif	/* EE_CORTEX_MX_INT_01_ISR */

#ifdef	EE_CORTEX_MX_INT_02_ISR
#ifdef	EE_CORTEX_MX_INT_02_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_02_NUM, EE_CORTEX_MX_INT_02_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_02_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_02_NUM);
#endif	/* EE_CORTEX_MX_INT_02_ISR */

#ifdef	EE_CORTEX_MX_INT_03_ISR
#ifdef	EE_CORTEX_MX_INT_03_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_03_NUM, EE_CORTEX_MX_INT_03_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_03_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_03_NUM);
#endif	/* EE_CORTEX_MX_INT_03_ISR */

#ifdef	EE_CORTEX_MX_INT_04_ISR
#ifdef	EE_CORTEX_MX_INT_04_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_04_NUM, EE_CORTEX_MX_INT_04_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_04_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_04_NUM);
#endif	/* EE_CORTEX_MX_INT_04_ISR */

#ifdef	EE_CORTEX_MX_INT_05_ISR
#ifdef	EE_CORTEX_MX_INT_05_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_05_NUM, EE_CORTEX_MX_INT_05_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_05_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_05_NUM);
#endif	/* EE_CORTEX_MX_INT_05_ISR */

#ifdef	EE_CORTEX_MX_INT_06_ISR
#ifdef	EE_CORTEX_MX_INT_06_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_06_NUM, EE_CORTEX_MX_INT_06_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_06_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_06_NUM);
#endif	/* EE_CORTEX_MX_INT_06_ISR */

#ifdef	EE_CORTEX_MX_INT_07_ISR
#ifdef	EE_CORTEX_MX_INT_07_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_07_NUM, EE_CORTEX_MX_INT_07_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_07_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_07_NUM);
#endif	/* EE_CORTEX_MX_INT_07_ISR */

#ifdef	EE_CORTEX_MX_INT_08_ISR
#ifdef	EE_CORTEX_MX_INT_08_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_08_NUM, EE_CORTEX_MX_INT_08_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_08_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_08_NUM);
#endif	/* EE_CORTEX_MX_INT_08_ISR */

#ifdef	EE_CORTEX_MX_INT_09_ISR
#ifdef	EE_CORTEX_MX_INT_09_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_09_NUM, EE_CORTEX_MX_INT_09_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_09_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_09_NUM);
#endif	/* EE_CORTEX_MX_INT_09_ISR */

#ifdef	EE_CORTEX_MX_INT_0A_ISR
#ifdef	EE_CORTEX_MX_INT_0A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0A_NUM, EE_CORTEX_MX_INT_0A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0A_NUM);
#endif	/* EE_CORTEX_MX_INT_0A_ISR */

#ifdef	EE_CORTEX_MX_INT_0B_ISR
#ifdef	EE_CORTEX_MX_INT_0B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0B_NUM, EE_CORTEX_MX_INT_0B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0B_NUM);
#endif	/* EE_CORTEX_MX_INT_0B_ISR */

#ifdef	EE_CORTEX_MX_INT_0C_ISR
#ifdef	EE_CORTEX_MX_INT_0C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0C_NUM, EE_CORTEX_MX_INT_0C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0C_NUM);
#endif	/* EE_CORTEX_MX_INT_0C_ISR */

#ifdef	EE_CORTEX_MX_INT_0D_ISR
#ifdef	EE_CORTEX_MX_INT_0D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0D_NUM, EE_CORTEX_MX_INT_0D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0D_NUM);
#endif	/* EE_CORTEX_MX_INT_0D_ISR */

#ifdef	EE_CORTEX_MX_INT_0E_ISR
#ifdef	EE_CORTEX_MX_INT_0E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0E_NUM, EE_CORTEX_MX_INT_0E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0E_NUM);
#endif	/* EE_CORTEX_MX_INT_0E_ISR */

#ifdef	EE_CORTEX_MX_INT_0F_ISR
#ifdef	EE_CORTEX_MX_INT_0F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_0F_NUM, EE_CORTEX_MX_INT_0F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_0F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_0F_NUM);
#endif	/* EE_CORTEX_MX_INT_0F_ISR */

#ifdef	EE_CORTEX_MX_INT_10_ISR
#ifdef	EE_CORTEX_MX_INT_10_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_10_NUM, EE_CORTEX_MX_INT_10_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_10_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_10_NUM);
#endif	/* EE_CORTEX_MX_INT_10_ISR */

#ifdef	EE_CORTEX_MX_INT_11_ISR
#ifdef	EE_CORTEX_MX_INT_11_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_11_NUM, EE_CORTEX_MX_INT_11_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_11_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_11_NUM);
#endif	/* EE_CORTEX_MX_INT_11_ISR */

#ifdef	EE_CORTEX_MX_INT_12_ISR
#ifdef	EE_CORTEX_MX_INT_12_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_12_NUM, EE_CORTEX_MX_INT_12_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_12_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_12_NUM);
#endif	/* EE_CORTEX_MX_INT_12_ISR */

#ifdef	EE_CORTEX_MX_INT_13_ISR
#ifdef	EE_CORTEX_MX_INT_13_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_13_NUM, EE_CORTEX_MX_INT_13_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_13_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_13_NUM);
#endif	/* EE_CORTEX_MX_INT_13_ISR */

#ifdef	EE_CORTEX_MX_INT_14_ISR
#ifdef	EE_CORTEX_MX_INT_14_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_14_NUM, EE_CORTEX_MX_INT_14_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_14_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_14_NUM);
#endif	/* EE_CORTEX_MX_INT_14_ISR */

#ifdef	EE_CORTEX_MX_INT_15_ISR
#ifdef	EE_CORTEX_MX_INT_15_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_15_NUM, EE_CORTEX_MX_INT_15_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_15_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_15_NUM);
#endif	/* EE_CORTEX_MX_INT_15_ISR */

#ifdef	EE_CORTEX_MX_INT_16_ISR
#ifdef	EE_CORTEX_MX_INT_16_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_16_NUM, EE_CORTEX_MX_INT_16_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_16_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_16_NUM);
#endif	/* EE_CORTEX_MX_INT_16_ISR */

#ifdef	EE_CORTEX_MX_INT_17_ISR
#ifdef	EE_CORTEX_MX_INT_17_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_17_NUM, EE_CORTEX_MX_INT_17_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_17_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_17_NUM);
#endif	/* EE_CORTEX_MX_INT_17_ISR */

#ifdef	EE_CORTEX_MX_INT_18_ISR
#ifdef	EE_CORTEX_MX_INT_18_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_18_NUM, EE_CORTEX_MX_INT_18_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_18_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_18_NUM);
#endif	/* EE_CORTEX_MX_INT_18_ISR */

#ifdef	EE_CORTEX_MX_INT_19_ISR
#ifdef	EE_CORTEX_MX_INT_19_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_19_NUM, EE_CORTEX_MX_INT_19_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_19_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_19_NUM);
#endif	/* EE_CORTEX_MX_INT_19_ISR */

#ifdef	EE_CORTEX_MX_INT_1A_ISR
#ifdef	EE_CORTEX_MX_INT_1A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1A_NUM, EE_CORTEX_MX_INT_1A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1A_NUM);
#endif	/* EE_CORTEX_MX_INT_1A_ISR */

#ifdef	EE_CORTEX_MX_INT_1B_ISR
#ifdef	EE_CORTEX_MX_INT_1B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1B_NUM, EE_CORTEX_MX_INT_1B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1B_NUM);
#endif	/* EE_CORTEX_MX_INT_1B_ISR */

#ifdef	EE_CORTEX_MX_INT_1C_ISR
#ifdef	EE_CORTEX_MX_INT_1C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1C_NUM, EE_CORTEX_MX_INT_1C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1C_NUM);
#endif	/* EE_CORTEX_MX_INT_1C_ISR */

#ifdef	EE_CORTEX_MX_INT_1D_ISR
#ifdef	EE_CORTEX_MX_INT_1D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1D_NUM, EE_CORTEX_MX_INT_1D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1D_NUM);
#endif	/* EE_CORTEX_MX_INT_1D_ISR */

#ifdef	EE_CORTEX_MX_INT_1E_ISR
#ifdef	EE_CORTEX_MX_INT_1E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1E_NUM, EE_CORTEX_MX_INT_1E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1E_NUM);
#endif	/* EE_CORTEX_MX_INT_1E_ISR */

#ifdef	EE_CORTEX_MX_INT_1F_ISR
#ifdef	EE_CORTEX_MX_INT_1F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_1F_NUM, EE_CORTEX_MX_INT_1F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_1F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_1F_NUM);
#endif	/* EE_CORTEX_MX_INT_1F_ISR */

#ifdef	EE_CORTEX_MX_INT_20_ISR
#ifdef	EE_CORTEX_MX_INT_20_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_20_NUM, EE_CORTEX_MX_INT_20_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_20_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_20_NUM);
#endif	/* EE_CORTEX_MX_INT_20_ISR */

#ifdef	EE_CORTEX_MX_INT_21_ISR
#ifdef	EE_CORTEX_MX_INT_21_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_21_NUM, EE_CORTEX_MX_INT_21_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_21_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_21_NUM);
#endif	/* EE_CORTEX_MX_INT_21_ISR */

#ifdef	EE_CORTEX_MX_INT_22_ISR
#ifdef	EE_CORTEX_MX_INT_22_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_22_NUM, EE_CORTEX_MX_INT_22_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_22_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_22_NUM);
#endif	/* EE_CORTEX_MX_INT_22_ISR */

#ifdef	EE_CORTEX_MX_INT_23_ISR
#ifdef	EE_CORTEX_MX_INT_23_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_23_NUM, EE_CORTEX_MX_INT_23_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_23_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_23_NUM);
#endif	/* EE_CORTEX_MX_INT_23_ISR */

#ifdef	EE_CORTEX_MX_INT_24_ISR
#ifdef	EE_CORTEX_MX_INT_24_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_24_NUM, EE_CORTEX_MX_INT_24_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_24_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_24_NUM);
#endif	/* EE_CORTEX_MX_INT_24_ISR */

#ifdef	EE_CORTEX_MX_INT_25_ISR
#ifdef	EE_CORTEX_MX_INT_25_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_25_NUM, EE_CORTEX_MX_INT_25_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_25_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_25_NUM);
#endif	/* EE_CORTEX_MX_INT_25_ISR */

#ifdef	EE_CORTEX_MX_INT_26_ISR
#ifdef	EE_CORTEX_MX_INT_26_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_26_NUM, EE_CORTEX_MX_INT_26_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_26_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_26_NUM);
#endif	/* EE_CORTEX_MX_INT_26_ISR */

#ifdef	EE_CORTEX_MX_INT_27_ISR
#ifdef	EE_CORTEX_MX_INT_27_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_27_NUM, EE_CORTEX_MX_INT_27_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_27_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_27_NUM);
#endif	/* EE_CORTEX_MX_INT_27_ISR */

#ifdef	EE_CORTEX_MX_INT_28_ISR
#ifdef	EE_CORTEX_MX_INT_28_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_28_NUM, EE_CORTEX_MX_INT_28_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_28_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_28_NUM);
#endif	/* EE_CORTEX_MX_INT_28_ISR */

#ifdef	EE_CORTEX_MX_INT_29_ISR
#ifdef	EE_CORTEX_MX_INT_29_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_29_NUM, EE_CORTEX_MX_INT_29_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_29_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_29_NUM);
#endif	/* EE_CORTEX_MX_INT_29_ISR */

#ifdef	EE_CORTEX_MX_INT_2A_ISR
#ifdef	EE_CORTEX_MX_INT_2A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2A_NUM, EE_CORTEX_MX_INT_2A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2A_NUM);
#endif	/* EE_CORTEX_MX_INT_2A_ISR */

#ifdef	EE_CORTEX_MX_INT_2B_ISR
#ifdef	EE_CORTEX_MX_INT_2B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2B_NUM, EE_CORTEX_MX_INT_2B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2B_NUM);
#endif	/* EE_CORTEX_MX_INT_2B_ISR */

#ifdef	EE_CORTEX_MX_INT_2C_ISR
#ifdef	EE_CORTEX_MX_INT_2C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2C_NUM, EE_CORTEX_MX_INT_2C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2C_NUM);
#endif	/* EE_CORTEX_MX_INT_2C_ISR */

#ifdef	EE_CORTEX_MX_INT_2D_ISR
#ifdef	EE_CORTEX_MX_INT_2D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2D_NUM, EE_CORTEX_MX_INT_2D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2D_NUM);
#endif	/* EE_CORTEX_MX_INT_2D_ISR */

#ifdef	EE_CORTEX_MX_INT_2E_ISR
#ifdef	EE_CORTEX_MX_INT_2E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2E_NUM, EE_CORTEX_MX_INT_2E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2E_NUM);
#endif	/* EE_CORTEX_MX_INT_2E_ISR */

#ifdef	EE_CORTEX_MX_INT_2F_ISR
#ifdef	EE_CORTEX_MX_INT_2F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_2F_NUM, EE_CORTEX_MX_INT_2F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_2F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_2F_NUM);
#endif	/* EE_CORTEX_MX_INT_2F_ISR */

#ifdef	EE_CORTEX_MX_INT_30_ISR
#ifdef	EE_CORTEX_MX_INT_30_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_30_NUM, EE_CORTEX_MX_INT_30_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_30_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_30_NUM);
#endif	/* EE_CORTEX_MX_INT_30_ISR */

#ifdef	EE_CORTEX_MX_INT_31_ISR
#ifdef	EE_CORTEX_MX_INT_31_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_31_NUM, EE_CORTEX_MX_INT_31_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_31_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_31_NUM);
#endif	/* EE_CORTEX_MX_INT_31_ISR */

#ifdef	EE_CORTEX_MX_INT_32_ISR
#ifdef	EE_CORTEX_MX_INT_32_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_32_NUM, EE_CORTEX_MX_INT_32_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_32_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_32_NUM);
#endif	/* EE_CORTEX_MX_INT_32_ISR */

#ifdef	EE_CORTEX_MX_INT_33_ISR
#ifdef	EE_CORTEX_MX_INT_33_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_33_NUM, EE_CORTEX_MX_INT_33_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_33_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_33_NUM);
#endif	/* EE_CORTEX_MX_INT_33_ISR */

#ifdef	EE_CORTEX_MX_INT_34_ISR
#ifdef	EE_CORTEX_MX_INT_34_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_34_NUM, EE_CORTEX_MX_INT_34_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_34_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_34_NUM);
#endif	/* EE_CORTEX_MX_INT_34_ISR */

#ifdef	EE_CORTEX_MX_INT_35_ISR
#ifdef	EE_CORTEX_MX_INT_35_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_35_NUM, EE_CORTEX_MX_INT_35_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_35_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_35_NUM);
#endif	/* EE_CORTEX_MX_INT_35_ISR */

#ifdef	EE_CORTEX_MX_INT_36_ISR
#ifdef	EE_CORTEX_MX_INT_36_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_36_NUM, EE_CORTEX_MX_INT_36_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_36_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_36_NUM);
#endif	/* EE_CORTEX_MX_INT_36_ISR */

#ifdef	EE_CORTEX_MX_INT_37_ISR
#ifdef	EE_CORTEX_MX_INT_37_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_37_NUM, EE_CORTEX_MX_INT_37_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_37_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_37_NUM);
#endif	/* EE_CORTEX_MX_INT_37_ISR */

#ifdef	EE_CORTEX_MX_INT_38_ISR
#ifdef	EE_CORTEX_MX_INT_38_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_38_NUM, EE_CORTEX_MX_INT_38_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_38_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_38_NUM);
#endif	/* EE_CORTEX_MX_INT_38_ISR */

#ifdef	EE_CORTEX_MX_INT_39_ISR
#ifdef	EE_CORTEX_MX_INT_39_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_39_NUM, EE_CORTEX_MX_INT_39_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_39_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_39_NUM);
#endif	/* EE_CORTEX_MX_INT_39_ISR */

#ifdef	EE_CORTEX_MX_INT_3A_ISR
#ifdef	EE_CORTEX_MX_INT_3A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3A_NUM, EE_CORTEX_MX_INT_3A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3A_NUM);
#endif	/* EE_CORTEX_MX_INT_3A_ISR */

#ifdef	EE_CORTEX_MX_INT_3B_ISR
#ifdef	EE_CORTEX_MX_INT_3B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3B_NUM, EE_CORTEX_MX_INT_3B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3B_NUM);
#endif	/* EE_CORTEX_MX_INT_3B_ISR */

#ifdef	EE_CORTEX_MX_INT_3C_ISR
#ifdef	EE_CORTEX_MX_INT_3C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3C_NUM, EE_CORTEX_MX_INT_3C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3C_NUM);
#endif	/* EE_CORTEX_MX_INT_3C_ISR */

#ifdef	EE_CORTEX_MX_INT_3D_ISR
#ifdef	EE_CORTEX_MX_INT_3D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3D_NUM, EE_CORTEX_MX_INT_3D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3D_NUM);
#endif	/* EE_CORTEX_MX_INT_3D_ISR */

#ifdef	EE_CORTEX_MX_INT_3E_ISR
#ifdef	EE_CORTEX_MX_INT_3E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3E_NUM, EE_CORTEX_MX_INT_3E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3E_NUM);
#endif	/* EE_CORTEX_MX_INT_3E_ISR */

#ifdef	EE_CORTEX_MX_INT_3F_ISR
#ifdef	EE_CORTEX_MX_INT_3F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_3F_NUM, EE_CORTEX_MX_INT_3F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_3F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_3F_NUM);
#endif	/* EE_CORTEX_MX_INT_3F_ISR */

#ifdef	EE_CORTEX_MX_INT_40_ISR
#ifdef	EE_CORTEX_MX_INT_40_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_40_NUM, EE_CORTEX_MX_INT_40_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_40_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_40_NUM);
#endif	/* EE_CORTEX_MX_INT_40_ISR */

#ifdef	EE_CORTEX_MX_INT_41_ISR
#ifdef	EE_CORTEX_MX_INT_41_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_41_NUM, EE_CORTEX_MX_INT_41_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_41_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_41_NUM);
#endif	/* EE_CORTEX_MX_INT_41_ISR */

#ifdef	EE_CORTEX_MX_INT_42_ISR
#ifdef	EE_CORTEX_MX_INT_42_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_42_NUM, EE_CORTEX_MX_INT_42_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_42_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_42_NUM);
#endif	/* EE_CORTEX_MX_INT_42_ISR */

#ifdef	EE_CORTEX_MX_INT_43_ISR
#ifdef	EE_CORTEX_MX_INT_43_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_43_NUM, EE_CORTEX_MX_INT_43_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_43_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_43_NUM);
#endif	/* EE_CORTEX_MX_INT_43_ISR */

#ifdef	EE_CORTEX_MX_INT_44_ISR
#ifdef	EE_CORTEX_MX_INT_44_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_44_NUM, EE_CORTEX_MX_INT_44_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_44_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_44_NUM);
#endif	/* EE_CORTEX_MX_INT_44_ISR */

#ifdef	EE_CORTEX_MX_INT_45_ISR
#ifdef	EE_CORTEX_MX_INT_45_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_45_NUM, EE_CORTEX_MX_INT_45_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_45_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_45_NUM);
#endif	/* EE_CORTEX_MX_INT_45_ISR */

#ifdef	EE_CORTEX_MX_INT_46_ISR
#ifdef	EE_CORTEX_MX_INT_46_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_46_NUM, EE_CORTEX_MX_INT_46_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_46_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_46_NUM);
#endif	/* EE_CORTEX_MX_INT_46_ISR */

#ifdef	EE_CORTEX_MX_INT_47_ISR
#ifdef	EE_CORTEX_MX_INT_47_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_47_NUM, EE_CORTEX_MX_INT_47_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_47_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_47_NUM);
#endif	/* EE_CORTEX_MX_INT_47_ISR */

#ifdef	EE_CORTEX_MX_INT_48_ISR
#ifdef	EE_CORTEX_MX_INT_48_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_48_NUM, EE_CORTEX_MX_INT_48_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_48_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_48_NUM);
#endif	/* EE_CORTEX_MX_INT_48_ISR */

#ifdef	EE_CORTEX_MX_INT_49_ISR
#ifdef	EE_CORTEX_MX_INT_49_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_49_NUM, EE_CORTEX_MX_INT_49_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_49_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_49_NUM);
#endif	/* EE_CORTEX_MX_INT_49_ISR */

#ifdef	EE_CORTEX_MX_INT_4A_ISR
#ifdef	EE_CORTEX_MX_INT_4A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4A_NUM, EE_CORTEX_MX_INT_4A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4A_NUM);
#endif	/* EE_CORTEX_MX_INT_4A_ISR */

#ifdef	EE_CORTEX_MX_INT_4B_ISR
#ifdef	EE_CORTEX_MX_INT_4B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4B_NUM, EE_CORTEX_MX_INT_4B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4B_NUM);
#endif	/* EE_CORTEX_MX_INT_4B_ISR */

#ifdef	EE_CORTEX_MX_INT_4C_ISR
#ifdef	EE_CORTEX_MX_INT_4C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4C_NUM, EE_CORTEX_MX_INT_4C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4C_NUM);
#endif	/* EE_CORTEX_MX_INT_4C_ISR */

#ifdef	EE_CORTEX_MX_INT_4D_ISR
#ifdef	EE_CORTEX_MX_INT_4D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4D_NUM, EE_CORTEX_MX_INT_4D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4D_NUM);
#endif	/* EE_CORTEX_MX_INT_4D_ISR */

#ifdef	EE_CORTEX_MX_INT_4E_ISR
#ifdef	EE_CORTEX_MX_INT_4E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4E_NUM, EE_CORTEX_MX_INT_4E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4E_NUM);
#endif	/* EE_CORTEX_MX_INT_4E_ISR */

#ifdef	EE_CORTEX_MX_INT_4F_ISR
#ifdef	EE_CORTEX_MX_INT_4F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_4F_NUM, EE_CORTEX_MX_INT_4F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_4F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_4F_NUM);
#endif	/* EE_CORTEX_MX_INT_4F_ISR */

#ifdef	EE_CORTEX_MX_INT_50_ISR
#ifdef	EE_CORTEX_MX_INT_50_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_50_NUM, EE_CORTEX_MX_INT_50_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_50_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_50_NUM);
#endif	/* EE_CORTEX_MX_INT_50_ISR */

#ifdef	EE_CORTEX_MX_INT_51_ISR
#ifdef	EE_CORTEX_MX_INT_51_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_51_NUM, EE_CORTEX_MX_INT_51_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_51_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_51_NUM);
#endif	/* EE_CORTEX_MX_INT_51_ISR */

#ifdef	EE_CORTEX_MX_INT_52_ISR
#ifdef	EE_CORTEX_MX_INT_52_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_52_NUM, EE_CORTEX_MX_INT_52_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_52_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_52_NUM);
#endif	/* EE_CORTEX_MX_INT_52_ISR */

#ifdef	EE_CORTEX_MX_INT_53_ISR
#ifdef	EE_CORTEX_MX_INT_53_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_53_NUM, EE_CORTEX_MX_INT_53_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_53_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_53_NUM);
#endif	/* EE_CORTEX_MX_INT_53_ISR */

#ifdef	EE_CORTEX_MX_INT_54_ISR
#ifdef	EE_CORTEX_MX_INT_54_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_54_NUM, EE_CORTEX_MX_INT_54_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_54_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_54_NUM);
#endif	/* EE_CORTEX_MX_INT_54_ISR */

#ifdef	EE_CORTEX_MX_INT_55_ISR
#ifdef	EE_CORTEX_MX_INT_55_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_55_NUM, EE_CORTEX_MX_INT_55_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_55_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_55_NUM);
#endif	/* EE_CORTEX_MX_INT_55_ISR */

#ifdef	EE_CORTEX_MX_INT_56_ISR
#ifdef	EE_CORTEX_MX_INT_56_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_56_NUM, EE_CORTEX_MX_INT_56_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_56_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_56_NUM);
#endif	/* EE_CORTEX_MX_INT_56_ISR */

#ifdef	EE_CORTEX_MX_INT_57_ISR
#ifdef	EE_CORTEX_MX_INT_57_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_57_NUM, EE_CORTEX_MX_INT_57_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_57_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_57_NUM);
#endif	/* EE_CORTEX_MX_INT_57_ISR */

#ifdef	EE_CORTEX_MX_INT_58_ISR
#ifdef	EE_CORTEX_MX_INT_58_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_58_NUM, EE_CORTEX_MX_INT_58_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_58_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_58_NUM);
#endif	/* EE_CORTEX_MX_INT_58_ISR */

#ifdef	EE_CORTEX_MX_INT_59_ISR
#ifdef	EE_CORTEX_MX_INT_59_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_59_NUM, EE_CORTEX_MX_INT_59_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_59_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_59_NUM);
#endif	/* EE_CORTEX_MX_INT_59_ISR */

#ifdef	EE_CORTEX_MX_INT_5A_ISR
#ifdef	EE_CORTEX_MX_INT_5A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5A_NUM, EE_CORTEX_MX_INT_5A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5A_NUM);
#endif	/* EE_CORTEX_MX_INT_5A_ISR */

#ifdef	EE_CORTEX_MX_INT_5B_ISR
#ifdef	EE_CORTEX_MX_INT_5B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5B_NUM, EE_CORTEX_MX_INT_5B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5B_NUM);
#endif	/* EE_CORTEX_MX_INT_5B_ISR */

#ifdef	EE_CORTEX_MX_INT_5C_ISR
#ifdef	EE_CORTEX_MX_INT_5C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5C_NUM, EE_CORTEX_MX_INT_5C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5C_NUM);
#endif	/* EE_CORTEX_MX_INT_5C_ISR */

#ifdef	EE_CORTEX_MX_INT_5D_ISR
#ifdef	EE_CORTEX_MX_INT_5D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5D_NUM, EE_CORTEX_MX_INT_5D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5D_NUM);
#endif	/* EE_CORTEX_MX_INT_5D_ISR */

#ifdef	EE_CORTEX_MX_INT_5E_ISR
#ifdef	EE_CORTEX_MX_INT_5E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5E_NUM, EE_CORTEX_MX_INT_5E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5E_NUM);
#endif	/* EE_CORTEX_MX_INT_5E_ISR */

#ifdef	EE_CORTEX_MX_INT_5F_ISR
#ifdef	EE_CORTEX_MX_INT_5F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_5F_NUM, EE_CORTEX_MX_INT_5F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_5F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_5F_NUM);
#endif	/* EE_CORTEX_MX_INT_5F_ISR */

#ifdef	EE_CORTEX_MX_INT_60_ISR
#ifdef	EE_CORTEX_MX_INT_60_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_60_NUM, EE_CORTEX_MX_INT_60_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_60_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_60_NUM);
#endif	/* EE_CORTEX_MX_INT_60_ISR */

#ifdef	EE_CORTEX_MX_INT_61_ISR
#ifdef	EE_CORTEX_MX_INT_61_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_61_NUM, EE_CORTEX_MX_INT_61_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_61_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_61_NUM);
#endif	/* EE_CORTEX_MX_INT_61_ISR */

#ifdef	EE_CORTEX_MX_INT_62_ISR
#ifdef	EE_CORTEX_MX_INT_62_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_62_NUM, EE_CORTEX_MX_INT_62_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_62_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_62_NUM);
#endif	/* EE_CORTEX_MX_INT_62_ISR */

#ifdef	EE_CORTEX_MX_INT_63_ISR
#ifdef	EE_CORTEX_MX_INT_63_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_63_NUM, EE_CORTEX_MX_INT_63_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_63_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_63_NUM);
#endif	/* EE_CORTEX_MX_INT_63_ISR */

#ifdef	EE_CORTEX_MX_INT_64_ISR
#ifdef	EE_CORTEX_MX_INT_64_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_64_NUM, EE_CORTEX_MX_INT_64_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_64_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_64_NUM);
#endif	/* EE_CORTEX_MX_INT_64_ISR */

#ifdef	EE_CORTEX_MX_INT_65_ISR
#ifdef	EE_CORTEX_MX_INT_65_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_65_NUM, EE_CORTEX_MX_INT_65_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_65_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_65_NUM);
#endif	/* EE_CORTEX_MX_INT_65_ISR */

#ifdef	EE_CORTEX_MX_INT_66_ISR
#ifdef	EE_CORTEX_MX_INT_66_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_66_NUM, EE_CORTEX_MX_INT_66_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_66_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_66_NUM);
#endif	/* EE_CORTEX_MX_INT_66_ISR */

#ifdef	EE_CORTEX_MX_INT_67_ISR
#ifdef	EE_CORTEX_MX_INT_67_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_67_NUM, EE_CORTEX_MX_INT_67_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_67_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_67_NUM);
#endif	/* EE_CORTEX_MX_INT_67_ISR */

#ifdef	EE_CORTEX_MX_INT_68_ISR
#ifdef	EE_CORTEX_MX_INT_68_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_68_NUM, EE_CORTEX_MX_INT_68_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_68_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_68_NUM);
#endif	/* EE_CORTEX_MX_INT_68_ISR */

#ifdef	EE_CORTEX_MX_INT_69_ISR
#ifdef	EE_CORTEX_MX_INT_69_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_69_NUM, EE_CORTEX_MX_INT_69_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_69_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_69_NUM);
#endif	/* EE_CORTEX_MX_INT_69_ISR */

#ifdef	EE_CORTEX_MX_INT_6A_ISR
#ifdef	EE_CORTEX_MX_INT_6A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6A_NUM, EE_CORTEX_MX_INT_6A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6A_NUM);
#endif	/* EE_CORTEX_MX_INT_6A_ISR */

#ifdef	EE_CORTEX_MX_INT_6B_ISR
#ifdef	EE_CORTEX_MX_INT_6B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6B_NUM, EE_CORTEX_MX_INT_6B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6B_NUM);
#endif	/* EE_CORTEX_MX_INT_6B_ISR */

#ifdef	EE_CORTEX_MX_INT_6C_ISR
#ifdef	EE_CORTEX_MX_INT_6C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6C_NUM, EE_CORTEX_MX_INT_6C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6C_NUM);
#endif	/* EE_CORTEX_MX_INT_6C_ISR */

#ifdef	EE_CORTEX_MX_INT_6D_ISR
#ifdef	EE_CORTEX_MX_INT_6D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6D_NUM, EE_CORTEX_MX_INT_6D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6D_NUM);
#endif	/* EE_CORTEX_MX_INT_6D_ISR */

#ifdef	EE_CORTEX_MX_INT_6E_ISR
#ifdef	EE_CORTEX_MX_INT_6E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6E_NUM, EE_CORTEX_MX_INT_6E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6E_NUM);
#endif	/* EE_CORTEX_MX_INT_6E_ISR */

#ifdef	EE_CORTEX_MX_INT_6F_ISR
#ifdef	EE_CORTEX_MX_INT_6F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_6F_NUM, EE_CORTEX_MX_INT_6F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_6F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_6F_NUM);
#endif	/* EE_CORTEX_MX_INT_6F_ISR */

#ifdef	EE_CORTEX_MX_INT_70_ISR
#ifdef	EE_CORTEX_MX_INT_70_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_70_NUM, EE_CORTEX_MX_INT_70_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_70_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_70_NUM);
#endif	/* EE_CORTEX_MX_INT_70_ISR */

#ifdef	EE_CORTEX_MX_INT_71_ISR
#ifdef	EE_CORTEX_MX_INT_71_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_71_NUM, EE_CORTEX_MX_INT_71_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_71_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_71_NUM);
#endif	/* EE_CORTEX_MX_INT_71_ISR */

#ifdef	EE_CORTEX_MX_INT_72_ISR
#ifdef	EE_CORTEX_MX_INT_72_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_72_NUM, EE_CORTEX_MX_INT_72_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_72_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_72_NUM);
#endif	/* EE_CORTEX_MX_INT_72_ISR */

#ifdef	EE_CORTEX_MX_INT_73_ISR
#ifdef	EE_CORTEX_MX_INT_73_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_73_NUM, EE_CORTEX_MX_INT_73_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_73_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_73_NUM);
#endif	/* EE_CORTEX_MX_INT_73_ISR */

#ifdef	EE_CORTEX_MX_INT_74_ISR
#ifdef	EE_CORTEX_MX_INT_74_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_74_NUM, EE_CORTEX_MX_INT_74_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_74_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_74_NUM);
#endif	/* EE_CORTEX_MX_INT_74_ISR */

#ifdef	EE_CORTEX_MX_INT_75_ISR
#ifdef	EE_CORTEX_MX_INT_75_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_75_NUM, EE_CORTEX_MX_INT_75_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_75_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_75_NUM);
#endif	/* EE_CORTEX_MX_INT_75_ISR */

#ifdef	EE_CORTEX_MX_INT_76_ISR
#ifdef	EE_CORTEX_MX_INT_76_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_76_NUM, EE_CORTEX_MX_INT_76_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_76_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_76_NUM);
#endif	/* EE_CORTEX_MX_INT_76_ISR */

#ifdef	EE_CORTEX_MX_INT_77_ISR
#ifdef	EE_CORTEX_MX_INT_77_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_77_NUM, EE_CORTEX_MX_INT_77_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_77_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_77_NUM);
#endif	/* EE_CORTEX_MX_INT_77_ISR */

#ifdef	EE_CORTEX_MX_INT_78_ISR
#ifdef	EE_CORTEX_MX_INT_78_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_78_NUM, EE_CORTEX_MX_INT_78_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_78_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_78_NUM);
#endif	/* EE_CORTEX_MX_INT_78_ISR */

#ifdef	EE_CORTEX_MX_INT_79_ISR
#ifdef	EE_CORTEX_MX_INT_79_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_79_NUM, EE_CORTEX_MX_INT_79_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_79_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_79_NUM);
#endif	/* EE_CORTEX_MX_INT_79_ISR */

#ifdef	EE_CORTEX_MX_INT_7A_ISR
#ifdef	EE_CORTEX_MX_INT_7A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7A_NUM, EE_CORTEX_MX_INT_7A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7A_NUM);
#endif	/* EE_CORTEX_MX_INT_7A_ISR */

#ifdef	EE_CORTEX_MX_INT_7B_ISR
#ifdef	EE_CORTEX_MX_INT_7B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7B_NUM, EE_CORTEX_MX_INT_7B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7B_NUM);
#endif	/* EE_CORTEX_MX_INT_7B_ISR */

#ifdef	EE_CORTEX_MX_INT_7C_ISR
#ifdef	EE_CORTEX_MX_INT_7C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7C_NUM, EE_CORTEX_MX_INT_7C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7C_NUM);
#endif	/* EE_CORTEX_MX_INT_7C_ISR */

#ifdef	EE_CORTEX_MX_INT_7D_ISR
#ifdef	EE_CORTEX_MX_INT_7D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7D_NUM, EE_CORTEX_MX_INT_7D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7D_NUM);
#endif	/* EE_CORTEX_MX_INT_7D_ISR */

#ifdef	EE_CORTEX_MX_INT_7E_ISR
#ifdef	EE_CORTEX_MX_INT_7E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7E_NUM, EE_CORTEX_MX_INT_7E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7E_NUM);
#endif	/* EE_CORTEX_MX_INT_7E_ISR */

#ifdef	EE_CORTEX_MX_INT_7F_ISR
#ifdef	EE_CORTEX_MX_INT_7F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_7F_NUM, EE_CORTEX_MX_INT_7F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_7F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_7F_NUM);
#endif	/* EE_CORTEX_MX_INT_7F_ISR */

#ifdef	EE_CORTEX_MX_INT_80_ISR
#ifdef	EE_CORTEX_MX_INT_80_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_80_NUM, EE_CORTEX_MX_INT_80_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_80_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_80_NUM);
#endif	/* EE_CORTEX_MX_INT_80_ISR */

#ifdef	EE_CORTEX_MX_INT_81_ISR
#ifdef	EE_CORTEX_MX_INT_81_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_81_NUM, EE_CORTEX_MX_INT_81_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_81_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_81_NUM);
#endif	/* EE_CORTEX_MX_INT_81_ISR */

#ifdef	EE_CORTEX_MX_INT_82_ISR
#ifdef	EE_CORTEX_MX_INT_82_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_82_NUM, EE_CORTEX_MX_INT_82_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_82_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_82_NUM);
#endif	/* EE_CORTEX_MX_INT_82_ISR */

#ifdef	EE_CORTEX_MX_INT_83_ISR
#ifdef	EE_CORTEX_MX_INT_83_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_83_NUM, EE_CORTEX_MX_INT_83_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_83_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_83_NUM);
#endif	/* EE_CORTEX_MX_INT_83_ISR */

#ifdef	EE_CORTEX_MX_INT_84_ISR
#ifdef	EE_CORTEX_MX_INT_84_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_84_NUM, EE_CORTEX_MX_INT_84_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_84_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_84_NUM);
#endif	/* EE_CORTEX_MX_INT_84_ISR */

#ifdef	EE_CORTEX_MX_INT_85_ISR
#ifdef	EE_CORTEX_MX_INT_85_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_85_NUM, EE_CORTEX_MX_INT_85_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_85_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_85_NUM);
#endif	/* EE_CORTEX_MX_INT_85_ISR */

#ifdef	EE_CORTEX_MX_INT_86_ISR
#ifdef	EE_CORTEX_MX_INT_86_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_86_NUM, EE_CORTEX_MX_INT_86_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_86_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_86_NUM);
#endif	/* EE_CORTEX_MX_INT_86_ISR */

#ifdef	EE_CORTEX_MX_INT_87_ISR
#ifdef	EE_CORTEX_MX_INT_87_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_87_NUM, EE_CORTEX_MX_INT_87_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_87_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_87_NUM);
#endif	/* EE_CORTEX_MX_INT_87_ISR */

#ifdef	EE_CORTEX_MX_INT_88_ISR
#ifdef	EE_CORTEX_MX_INT_88_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_88_NUM, EE_CORTEX_MX_INT_88_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_88_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_88_NUM);
#endif	/* EE_CORTEX_MX_INT_88_ISR */

#ifdef	EE_CORTEX_MX_INT_89_ISR
#ifdef	EE_CORTEX_MX_INT_89_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_89_NUM, EE_CORTEX_MX_INT_89_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_89_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_89_NUM);
#endif	/* EE_CORTEX_MX_INT_89_ISR */

#ifdef	EE_CORTEX_MX_INT_8A_ISR
#ifdef	EE_CORTEX_MX_INT_8A_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8A_NUM, EE_CORTEX_MX_INT_8A_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8A_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8A_NUM);
#endif	/* EE_CORTEX_MX_INT_8A_ISR */

#ifdef	EE_CORTEX_MX_INT_8B_ISR
#ifdef	EE_CORTEX_MX_INT_8B_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8B_NUM, EE_CORTEX_MX_INT_8B_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8B_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8B_NUM);
#endif	/* EE_CORTEX_MX_INT_8B_ISR */

#ifdef	EE_CORTEX_MX_INT_8C_ISR
#ifdef	EE_CORTEX_MX_INT_8C_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8C_NUM, EE_CORTEX_MX_INT_8C_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8C_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8C_NUM);
#endif	/* EE_CORTEX_MX_INT_8C_ISR */

#ifdef	EE_CORTEX_MX_INT_8D_ISR
#ifdef	EE_CORTEX_MX_INT_8D_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8D_NUM, EE_CORTEX_MX_INT_8D_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8D_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8D_NUM);
#endif	/* EE_CORTEX_MX_INT_8D_ISR */

#ifdef	EE_CORTEX_MX_INT_8E_ISR
#ifdef	EE_CORTEX_MX_INT_8E_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8E_NUM, EE_CORTEX_MX_INT_8E_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8E_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8E_NUM);
#endif	/* EE_CORTEX_MX_INT_8E_ISR */

#ifdef	EE_CORTEX_MX_INT_8F_ISR
#ifdef	EE_CORTEX_MX_INT_8F_ISR_PRI
	NVIC_SET_PRI(EE_CORTEX_MX_INT_8F_NUM, EE_CORTEX_MX_INT_8F_ISR_PRI);
#endif	/* EE_CORTEX_MX_INT_8F_ISR_PRI */
	NVIC_INT_ENABLE(EE_CORTEX_MX_INT_8F_NUM);
#endif	/* EE_CORTEX_MX_INT_8F_ISR */

#endif	/* __CORTEX_M4__ */

  EE_hal_resumeIRQ(flags);

}
